==> vscode-lit-xml-0.5.0.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

# [0.5.0](https://github.com/nicojs/lit-xml/compare/v0.4.6...v0.5.0) (2022-03-09)

**Note:** Version bump only for package vscode-lit-xml





## [0.4.6](https://github.com/nicojs/lit-xml/compare/v0.4.5...v0.4.6) (2021-11-10)

**Note:** Version bump only for package vscode-lit-xml





## [0.4.5](https://github.com/nicojs/lit-xml/compare/v0.4.4...v0.4.5) (2021-09-03)

**Note:** Version bump only for package vscode-lit-xml





## [0.4.4](https://github.com/nicojs/lit-xml/compare/v0.4.3...v0.4.4) (2021-08-18)


### Bug Fixes

* **vscode-lit-xml:** set virtualWorkspaces: true ([a5181ea](https://github.com/nicojs/lit-xml/commit/a5181ea0704858ef486c80703915118615de6eef))





## [0.4.3](https://github.com/nicojs/lit-xml/compare/v0.4.2...v0.4.3) (2021-08-18)

**Note:** Version bump only for package vscode-lit-xml





## [0.4.2](https://github.com/nicojs/lit-xml/compare/v0.4.1...v0.4.2) (2021-08-18)

**Note:** Version bump only for package vscode-lit-xml





## [0.4.1](https://github.com/nicojs/lit-xml/compare/v0.4.0...v0.4.1) (2021-08-17)


### Bug Fixes

* **vscode-lit-xml:** remove activation point from extension ([0dcc3ef](https://github.com/nicojs/lit-xml/commit/0dcc3ef3804c9cc3f8afd798c0b0ea75aa25ac97))





# [0.4.0](https://github.com/nicojs/lit-xml/compare/v0.3.1...v0.4.0) (2021-04-12)

**Note:** Version bump only for package vscode-lit-xml





## [0.3.1](https://github.com/nicojs/lit-xml/compare/v0.3.0...v0.3.1) (2021-04-08)

**Note:** Version bump only for package vscode-lit-xml





# [0.3.0](https://github.com/nicojs/lit-xml/compare/v0.2.2...v0.3.0) (2020-05-11)


### Features

* **vscode:** add icon to package ([#8](https://github.com/nicojs/lit-xml/issues/8)) ([a921cd2](https://github.com/nicojs/lit-xml/commit/a921cd2283f452ad766b555209e0daed6712af27))





## [0.2.2](https://github.com/nicojs/lit-xml/compare/v0.2.1...v0.2.2) (2020-05-11)

**Note:** Version bump only for package vscode-lit-xml





## [0.2.1](https://github.com/nicojs/lit-xml/compare/v0.2.0...v0.2.1) (2020-05-11)

**Note:** Version bump only for package vscode-lit-xml

==> vscode-lit-xml-0.6.0.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

# [0.6.0](https://github.com/nicojs/lit-xml/compare/v0.5.0...v0.6.0) (2023-06-28)

**Note:** Version bump only for package vscode-lit-xml

# [0.5.0](https://github.com/nicojs/lit-xml/compare/v0.4.6...v0.5.0) (2022-03-09)

**Note:** Version bump only for package vscode-lit-xml

## [0.4.6](https://github.com/nicojs/lit-xml/compare/v0.4.5...v0.4.6) (2021-11-10)

**Note:** Version bump only for package vscode-lit-xml

## [0.4.5](https://github.com/nicojs/lit-xml/compare/v0.4.4...v0.4.5) (2021-09-03)

**Note:** Version bump only for package vscode-lit-xml

## [0.4.4](https://github.com/nicojs/lit-xml/compare/v0.4.3...v0.4.4) (2021-08-18)

### Bug Fixes

- **vscode-lit-xml:** set virtualWorkspaces: true ([a5181ea](https://github.com/nicojs/lit-xml/commit/a5181ea0704858ef486c80703915118615de6eef))

## [0.4.3](https://github.com/nicojs/lit-xml/compare/v0.4.2...v0.4.3) (2021-08-18)

**Note:** Version bump only for package vscode-lit-xml

## [0.4.2](https://github.com/nicojs/lit-xml/compare/v0.4.1...v0.4.2) (2021-08-18)

**Note:** Version bump only for package vscode-lit-xml

## [0.4.1](https://github.com/nicojs/lit-xml/compare/v0.4.0...v0.4.1) (2021-08-17)

### Bug Fixes

- **vscode-lit-xml:** remove activation point from extension ([0dcc3ef](https://github.com/nicojs/lit-xml/commit/0dcc3ef3804c9cc3f8afd798c0b0ea75aa25ac97))

# [0.4.0](https://github.com/nicojs/lit-xml/compare/v0.3.1...v0.4.0) (2021-04-12)

**Note:** Version bump only for package vscode-lit-xml

## [0.3.1](https://github.com/nicojs/lit-xml/compare/v0.3.0...v0.3.1) (2021-04-08)

**Note:** Version bump only for package vscode-lit-xml

# [0.3.0](https://github.com/nicojs/lit-xml/compare/v0.2.2...v0.3.0) (2020-05-11)

### Features

- **vscode:** add icon to package ([#8](https://github.com/nicojs/lit-xml/issues/8)) ([a921cd2](https://github.com/nicojs/lit-xml/commit/a921cd2283f452ad766b555209e0daed6712af27))

## [0.2.2](https://github.com/nicojs/lit-xml/compare/v0.2.1...v0.2.2) (2020-05-11)

**Note:** Version bump only for package vscode-lit-xml

## [0.2.1](https://github.com/nicojs/lit-xml/compare/v0.2.0...v0.2.1) (2020-05-11)

**Note:** Version bump only for package vscode-lit-xml
